@@ -37,10 +37,10 @@ class ReporterAction(argparse.Action):
 
     def __call__(  # type: ignore  # noqa: D102
         self,
-        parser: argparse.ArgumentParser,
+        parser: argparse.ArgumentParser,  # noqa: U100
         namespace: argparse.Namespace,
         value: str,
-        option_string: str,
+        option_string: str,  # noqa: U100
     ) -> None:
         reporter: t.Dict[str, t.Any] = {}
         if value:
@@ -142,7 +142,7 @@ def build_main_parser() -> argparse.ArgumentParser:  # noqa: D103
             " id with the syntax '<OPTION>=<JSON VALUE>'. Console reporters can"
             " take an argument 'color' which accepts a JSON object to customize"
             " the colors for parts of the report like files, for example:"
-            " table:simple;color={%s}." % example
+            " table:simple;colors={%s}." % example
         ),
     )
     parser.add_argument(
@@ -190,13 +190,30 @@ def _parse_command_args(
             parser = argparse.ArgumentParser(prog="project-config show")
             parser.add_argument(
                 "data",
-                choices=["config", "style", "cache", "plugins"],
+                choices=["config", "style", "cache", "plugins", "file"],
                 help=(
                     "Indicate which data must be shown, discovered"
-                    " configuration, extended style or cache directory"
-                    " location."
+                    " configuration (config), extended style (style),"
+                    " cache directory location (cache), plugins with"
+                    " their actions (plugins) or a file as a"
+                    " serialized object (file <path>)."
                 ),
             )
+            args, remaining = parser.parse_known_args(subcommand_args)
+            if args.data == "file":
+                parser = argparse.ArgumentParser(
+                    prog="project-config show file",
+                )
+                parser.add_argument(
+                    "file",
+                    type=str,
+                    help=(
+                        "File to deserialize and show. This is useful for"
+                        " debugging purposes."
+                    ),
+                )
+                subargs, remaining = parser.parse_known_args(remaining)
+                args.__dict__.update(subargs.__dict__)
         else:  # command == "clean"
             parser = argparse.ArgumentParser(prog="project-config clean")
             parser.add_argument(
@@ -207,7 +224,8 @@ def _parse_command_args(
                     " 'cache' is the possible data to clean."
                 ),
             )
-        args, remaining = parser.parse_known_args(subcommand_args)
+            args, remaining = parser.parse_known_args(subcommand_args)
+
     else:
         args = argparse.Namespace()
         remaining = subcommand_args
@@ -235,7 +253,7 @@ def parse_args(argv: t.List[str]) -> argparse.Namespace:  # noqa: D103
     return argparse.Namespace(**vars(args), **vars(subargs))
 
 
-def run(argv: t.List[str] = []) -> int:  # noqa: D103
+def run(argv: t.List[str]) -> int:  # noqa: D103
     os.environ["PROJECT_CONFIG"] = "true"
     args = parse_args(argv)
 
