@@ -79,9 +79,8 @@ def fetch(url: str, **kwargs: t.Any) -> FetchResult:
     except ImportError:
         raise SchemeProtocolNotImplementedError(scheme)
 
-    fetch_func = getattr(module, "fetch")
     try:
-        string = fetch_func(url_parts, **kwargs)
+        string = module.fetch(url_parts, **kwargs)
     except FileNotFoundError:
         raise FetchError(f"'{url}' file not found")
     except ProjectConfigTimeoutError as exc:
@@ -109,7 +108,11 @@ def resolve_url(url: str) -> t.Tuple[str, str]:
     except ImportError:  # pragma: no cover
         raise SchemeProtocolNotImplementedError(scheme, action="Resolving")
     return (
-        getattr(module, "resolve_url", lambda url_parts_: url)(url_parts),
+        getattr(
+            module,
+            "resolve_url",
+            lambda url_parts_: url,  # noqa: U100
+        )(url_parts),
         scheme,
     )
 
