@@ -23,9 +23,9 @@ class SerializerFunction(Protocol):
 
     def __call__(  # noqa: D102
         self,
-        value: t.Any,
-        **kwargs: t.Any,
-    ) -> SerializerResult:  # pragma: no cover
+        value: t.Any,  # noqa: U100
+        **kwargs: t.Any,  # noqa: U100
+    ) -> SerializerResult:
         ...
 
 
