@@ -191,6 +191,33 @@ def _to_items(value: t.Any) -> t.List[t.Any]:
 class JMESPathProjectConfigFunctions(JMESPathFunctions):
     """JMESPath class to include custom functions."""
 
+    # Functions that expands the functionality of the standard JMESPath
+    # functions:
+
+    @jmespath_func_signature(
+        {"types": ["string"]},
+        {"types": ["string", "array-string"], "variadic": True},
+    )
+    def _func_starts_with(
+        self, search: str, suffix: t.Union[str, t.Tuple[str]], *args: t.Any
+    ) -> bool:
+        if isinstance(suffix, list):
+            suffix = tuple(suffix)
+        return search.startswith(suffix, *args)
+
+    @jmespath_func_signature(
+        {"types": ["string"]},
+        {"types": ["string", "array-string"], "variadic": True},
+    )
+    def _func_ends_with(
+        self, search: str, suffix: t.Union[str, t.Tuple[str]], *args: t.Any
+    ) -> bool:
+        if isinstance(suffix, list):
+            suffix = tuple(suffix)
+        return search.endswith(suffix, *args)
+
+    # Functions that expands the standard JMESPath functions:
+
     @jmespath_func_signature(
         {"types": ["string"]},
         {"types": ["string"], "variadic": True},
@@ -236,6 +263,10 @@ class JMESPathProjectConfigFunctions(JMESPathFunctions):
     ) -> str:
         return re.sub(regex, repl, value, *args)
 
+    @jmespath_func_signature({"types": ["string"]})
+    def _func_regex_escape(self, regex: str) -> str:
+        return re.escape(regex)
+
     @jmespath_func_signature(
         {"types": []},
         {"types": ["string"]},
@@ -593,8 +624,10 @@ class JMESPathProjectConfigFunctions(JMESPathFunctions):
     )
 
 
+project_config_options = JMESPathProjectConfigFunctions()
+
 jmespath_options = JMESPathOptions(
-    custom_functions=JMESPathProjectConfigFunctions(),
+    custom_functions=project_config_options,
 )
 
 
@@ -974,7 +1007,21 @@ def smart_fixer_by_expected_value(
                         merge_strategy,
                         deep,
                     )
-
+    elif (
+        ast["type"] == "function_expression"
+        and ast["value"] == "contains"
+        and len(ast.get("children", [])) == 2
+        and ast["children"][0]["type"] == "function_expression"
+        and ast["children"][0]["value"] == "keys"
+        and ast["children"][0].get("children")
+        and ast["children"][0]["children"][0]["type"] == "current"
+        and ast["children"][1]["type"] == "literal"
+    ):
+        if expected_value is False:
+            # contains(keys(@), 'key') -> false
+            key = ast["children"][1]["value"]
+            fixer_expression = f"unset(@, '{key}')"
+        return fixer_expression
     else:  # pragma: no cover
         return fixer_expression
 
